@@ -25,7 +25,11 @@ class SportsDataIOmeta(SportsDataIOMetalike):
             raise ValueError("JWTController did not find an environment variable matching the specified key.")
         SportsDataIOSingleton.key = key
         SportsDataIOSingleton.domain = domain
+        self.key = key
+        self.domain = domain
 
+
+    @property
     def get_key(self)->str:
         return SportsDataIOSingleton.key
 
